==> frysk-0.0.0.20051116.tar.gz: frysk-0.0.0.20051116/frysk-core/frysk/proc/HostState.java <==
// This file is part of the program FRYSK.
//
// Copyright 2005, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.proc;

/**
 * Possible host states.
 */

class HostState
    extends State
{
    /**
     * Return the hosts initial state.
     */
    static HostState initial (Host host)
    {
	return running;
    }
    protected HostState (String state)
    {
	super (state);
    }
    HostState processRequestRefresh (Host host, boolean refreshAll)
    {
	throw unhandled (host, "RequestRefresh");
    }
    HostState processRequestCreateAttachedProc (Host host,
						String stdin, String stdout,
						String stderr, String[] args)
    {
	throw unhandled (host, "PerformCreateAttachedProc");
    }

    private static HostState running = new HostState ("running")
	{
	    HostState processRequestRefresh (Host host, boolean refreshAll)
	    {
		host.sendRefresh (refreshAll);
		return running;
	    }
	    HostState processRequestCreateAttachedProc (Host host,
							String stdin,
							String stdout,
							String stderr,
							String[] args)
	    {
		host.sendCreateAttachedProc (stdin, stdout, stderr, args);
		return HostState.running;
	    }
	};
}

==> frysk-0.0.0.20051128.2.tar.gz: frysk-0.0.0.20051128.2/frysk-core/frysk/proc/HostState.java <==
// This file is part of the program FRYSK.
//
// Copyright 2005, Red Hat Inc.
//
// FRYSK is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//
// FRYSK is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with FRYSK; if not, write to the Free Software Foundation,
// Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
// 
// In addition, as a special exception, Red Hat, Inc. gives You the
// additional right to link the code of FRYSK with code not covered
// under the GNU General Public License ("Non-GPL Code") and to
// distribute linked combinations including the two, subject to the
// limitations in this paragraph. Non-GPL Code permitted under this
// exception must only link to the code of FRYSK through those well
// defined interfaces identified in the file named EXCEPTION found in
// the source code files (the "Approved Interfaces"). The files of
// Non-GPL Code may instantiate templates or use macros or inline
// functions from the Approved Interfaces without causing the
// resulting work to be covered by the GNU General Public
// License. Only Red Hat, Inc. may make changes or additions to the
// list of Approved Interfaces. You must obey the GNU General Public
// License in all respects for all of the FRYSK code and other code
// used in conjunction with FRYSK except the Non-GPL Code covered by
// this exception. If you modify this file, you may extend this
// exception to your version of the file, but you are not obligated to
// do so. If you do not wish to provide this exception without
// modification, you must delete this exception statement from your
// version and license this file solely under the GPL without
// exception.

package frysk.proc;

/**
 * Possible host states.
 */

import java.util.logging.Level;
import java.util.logging.Logger;
import frysk.Config;

class HostState
    extends State
{
    private static Logger logger = Logger.getLogger (Config.FRYSK_LOG_ID);
    /**
     * Return the hosts initial state.
     */
    static HostState initial (Host host)
    {
	return running;
    }
    protected HostState (String state)
    {
	super (state);
    }
    HostState processRequestRefresh (Host host, boolean refreshAll)
    {
	logger.log (Level.FINE, "", this); 
	throw unhandled (host, "RequestRefresh");
    }
    HostState processRequestCreateAttachedProc (Host host,
						String stdin, String stdout,
						String stderr, String[] args)
    {
	logger.log (Level.FINE, "", this); 
	throw unhandled (host, "PerformCreateAttachedProc");
    }

    private static HostState running = new HostState ("running")
	{
	    HostState processRequestRefresh (Host host, boolean refreshAll)
	    {
		logger.log (Level.FINE, "", this); 
		host.sendRefresh (refreshAll);
		return running;
	    }
	    HostState processRequestCreateAttachedProc (Host host,
							String stdin,
							String stdout,
							String stderr,
							String[] args)
	    {
		logger.log (Level.FINE, "", this); 
		host.sendCreateAttachedProc (stdin, stdout, stderr, args);
		return HostState.running;
	    }
	};
}
